==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/vi.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'vi', {
	button: {
		title: 'Thuộc tính của nút',
		text: 'Chuỗi hiển thị (giá trị)',
		type: 'Kiểu',
		typeBtn: 'Nút bấm',
		typeSbm: 'Nút gửi',
		typeRst: 'Nút nhập lại'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Thuộc tính nút kiểm',
		radioTitle: 'Thuộc tính nút chọn',
		value: 'Giá trị',
		selected: 'Được chọn'
	},
	form: {
		title: 'Thuộc tính biểu mẫu',
		menu: 'Thuộc tính biểu mẫu',
		action: 'Hành động',
		method: 'Phương thức',
		encoding: 'Bảng mã'
	},
	hidden: {
		title: 'Thuộc tính trường ẩn',
		name: 'Tên',
		value: 'Giá trị'
	},
	select: {
		title: 'Thuộc tính ô chọn',
		selectInfo: 'Thông tin',
		opAvail: 'Các tùy chọn có thể sử dụng',
		value: 'Giá trị',
		size: 'Kích cỡ',
		lines: 'dòng',
		chkMulti: 'Cho phép chọn nhiều',
		opText: 'Văn bản',
		opValue: 'Giá trị',
		btnAdd: 'Thêm',
		btnModify: 'Thay đổi',
		btnUp: 'Lên',
		btnDown: 'Xuống',
		btnSetValue: 'Giá trị được chọn',
		btnDelete: 'Nút xoá'
	},
	textarea: {
		title: 'Thuộc tính vùng văn bản',
		cols: 'Số cột',
		rows: 'Số hàng'
	},
	textfield: {
		title: 'Thuộc tính trường văn bản',
		name: 'Tên',
		value: 'Giá trị',
		charWidth: 'Độ rộng của ký tự',
		maxChars: 'Số ký tự tối đa',
		type: 'Kiểu',
		typeText: 'Ký tự',
		typePass: 'Mật khẩu',
		typeEmail: 'Email',
		typeSearch: 'Tìm kiếm',
		typeTel: 'Số điện thoại',
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/forms/lang/vi.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'vi', {
	button: {
		title: 'Thuộc tính của nút',
		text: 'Chuỗi hiển thị (giá trị)',
		type: 'Kiểu',
		typeBtn: 'Nút bấm',
		typeSbm: 'Nút gửi',
		typeRst: 'Nút nhập lại'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Thuộc tính nút kiểm',
		radioTitle: 'Thuộc tính nút chọn',
		value: 'Giá trị',
		selected: 'Được chọn',
		required: 'Required' // MISSING
	},
	form: {
		title: 'Thuộc tính biểu mẫu',
		menu: 'Thuộc tính biểu mẫu',
		action: 'Hành động',
		method: 'Phương thức',
		encoding: 'Bảng mã'
	},
	hidden: {
		title: 'Thuộc tính trường ẩn',
		name: 'Tên',
		value: 'Giá trị'
	},
	select: {
		title: 'Thuộc tính ô chọn',
		selectInfo: 'Thông tin',
		opAvail: 'Các tùy chọn có thể sử dụng',
		value: 'Giá trị',
		size: 'Kích cỡ',
		lines: 'dòng',
		chkMulti: 'Cho phép chọn nhiều',
		required: 'Required', // MISSING
		opText: 'Văn bản',
		opValue: 'Giá trị',
		btnAdd: 'Thêm',
		btnModify: 'Thay đổi',
		btnUp: 'Lên',
		btnDown: 'Xuống',
		btnSetValue: 'Giá trị được chọn',
		btnDelete: 'Nút xoá'
	},
	textarea: {
		title: 'Thuộc tính vùng văn bản',
		cols: 'Số cột',
		rows: 'Số hàng'
	},
	textfield: {
		title: 'Thuộc tính trường văn bản',
		name: 'Tên',
		value: 'Giá trị',
		charWidth: 'Độ rộng của ký tự',
		maxChars: 'Số ký tự tối đa',
		required: 'Required', // MISSING
		type: 'Kiểu',
		typeText: 'Ký tự',
		typePass: 'Mật khẩu',
		typeEmail: 'Email',
		typeSearch: 'Tìm kiếm',
		typeTel: 'Số điện thoại',
		typeUrl: 'URL'
	}
} );
